<?php
/*
 * Plugin Name: 3DPrint - Frontend Discount Table
 * Author: Sergey Burkov
 * Description: Displays discount table on the frontend
 * Text Domain: 3dprint-discount-table
 * WC requires at least: 3.0
 * WC tested up to: 9.7.9
 * Version: 1.0
*/

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

register_activation_hook( __FILE__, 'p3d_discount_table_check_install' );

add_action( 'before_woocommerce_init', function() {
	if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
		\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
	}
} );

require 'includes/ext/plugin-update-checker/plugin-update-checker.php';
use YahnisElsts\PluginUpdateChecker\v5\PucFactory;


if ( is_admin() ) {
	include '3dprint-discount-table-admin.php';

	#$dt_update_checker = PucFactory::buildUpdateChecker('http://srv1.wp3dprinting.com/wp-update-server/?action=get_metadata&slug=3dprint_discount_table', __FILE__, '3dprint_discount_table' );
	#$dt_update_checker->addQueryArgFilter('dt_filter_update_checks');
}

add_action( 'wp_enqueue_scripts', 'p3d_discount_table_enqueue_scripts_frontend' );
function p3d_discount_table_enqueue_scripts_frontend() {
	$settings = get_option( '3dp_discount_table_settings' );

	wp_enqueue_script( 'p3d-discount_table-script.js',  plugin_dir_url( __FILE__ ).'js/p3d_discount_table.js', array( '3dprint-frontend.js' ), '1.0' );

	$settings = get_option( '3dp_discount_table_settings' );
	$discount_table = array();

	if ( isset( $settings['discount_table'] ) && count($settings['discount_table'])) {
		foreach ($settings['discount_table'] as $setting) {
			$discount_table[$setting['qty']] = $setting['discount'];
		}
		ksort($discount_table, SORT_NUMERIC);
	}

	wp_localize_script( 'p3d-discount_table-script.js', 'p3d_discount_table',
		array(
			'discount_table' => $discount_table,
			'text_qty' => __('QTY', '3dprint-discount-table'),
			'text_discount' => __('Discount', '3dprint-discount-table'),
			'text_unit_price' => __('Unit Price', '3dprint-discount-table'),
			'text_total_price' => __('Total Price', '3dprint-discount-table')
		)
	);
}

function p3d_discount_table_check_install() {
	global $wpdb;
	$current_settings = get_option( '3dp_discount_table_settings' );
	$settings=array(
		'discount_table' => (isset($current_settings['discount_table']) ? $current_settings['discount_table'] : array())
	);
	update_option( '3dp_discount_table_settings', $settings );
}



?>